function handleOut = ResizeBox(handle, units, sizeX, sizeY)
% RESIZEBOX(H, UNITS, WIDTH, HEIGHT)
% RESIZEBOX(H, UNITS, [WIDTH HEIGHT])
% 
% Resizes object H to the specified WIDTH and HEIGHT, measured in the
% specified UNITS relative to the parent object of H. The centre point
% of H does not move.
% 
% H may be any object that has a 4-element 'Position' property, such
% as a FIGURE, AXES or UICONTROL.
% 
% See also POSITIONBOX, MEASURE

% Part of PFCMP version 2.5.41, an extension to the PSIGNIFIT toolbox for MATLAB versions 5 and up.
% The license and NO WARRANTY statement for PSIGNIFIT also applies to this release - see psych_legal.m
% Copyright (c) J.Hill 2002.
% mailto:psignifit@bootstrap-software.org
% http://www.bootstrap-software.org/psignifit/

if ~ishandle(handle), error('H must be a valid FIGURE, AXES or UICONTROL handle'), end
if isempty(strmatch(get(handle, 'type'), {'figure', 'axes', 'uicontrol'}, 'exact'))
	error('H must be a valid FIGURE, AXES or UICONTROL handle')
end
if nargin < 4, sizeY = []; end
if nargin < 3, sizeX = []; end
siz = [sizeX(:)' sizeY(:)'];
if ~isstr(units)
	siz = [units(:)' siz];
	units = get(handle, 'units');
end
if length(siz) == 1, siz = [siz nan]; end
if length(siz) ~= 2, error('too many numeric inputs'), end

oldUnits = get(handle, 'units');
set(handle, 'units', units)

pos = get(handle, 'position');
if isnan(siz(1)), siz(1) = siz(2) * pos(3)/pos(4); end
if isnan(siz(2)), siz(2) = siz(1) * pos(4)/pos(3); end
pos(1:2) = pos(1:2) + pos(3:4)/2 - siz/2;
pos(3:4) = siz;
set(handle, 'position', pos)
set(handle, 'units', oldUnits)

if nargout, handleOut = handle; end
